@@ -42,4 +42,19 @@ urlpatterns = patterns(
         {},
         name='category_object_detail'
     ),
+
+    # Admin ajax urls
+    (
+        r'^admin/molo/publish-ajax/$',
+        'molo.admin_views.publish_ajax',
+        {},
+        'molo-publish-ajax',
+    ),
+
+    (
+        r'^admin/molo/unpublish-ajax/$',
+        'molo.admin_views.unpublish_ajax',
+        {},
+        'molo-unpublish-ajax',
+    ),
 )
